<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="75"/>
        <source>MX Repo Manager</source>
        <translation>MX Repo Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="499"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Scegli il Repository di APT da utilizzare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX repos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Seleziona l&apos;MX-repo più veloce per me </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>search</source>
        <translation>cerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Debian repos</source>
        <translation>Debian repos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Seleziona il Debian-repo più veloce per me </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Individual sources</source>
        <translation>Sorgenti individuali</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="256"/>
        <source>Restore original APT sources</source>
        <translation>Ripristina le sorgenti originali di APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Display help </source>
        <translation>Visualizza la guida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>Quit application</source>
        <translation>Esci dall&apos;applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="448"/>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="67"/>
        <source>Please wait...</source>
        <translation>Attendi...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="128"/>
        <location filename="../mainwindow.cpp" line="368"/>
        <location filename="../mainwindow.cpp" line="620"/>
        <source>Success</source>
        <translation>Operazione riuscita</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="129"/>
        <location filename="../mainwindow.cpp" line="369"/>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>La tua selezione avrà effetto col prossimo aggiornamento delle sorgenti dei repository.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="201"/>
        <source>Lists</source>
        <translation>Elenchi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="201"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Sorgenti (le sorgenti vidimate sono abilitate)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <location filename="../mainwindow.cpp" line="549"/>
        <location filename="../mainwindow.cpp" line="560"/>
        <location filename="../mainwindow.cpp" line="578"/>
        <location filename="../mainwindow.cpp" line="606"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Could not change the repo.</source>
        <translation>Repository non modificabile</translation>
    </message>
    <message>
        <source>About MX Repo Manager</source>
        <translation type="vanished">Informazioni su MX Repo Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="416"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Programma per selezionare il Repository di APT predefinito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licenza</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Changelog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="442"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="443"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Hai selezionato MX Test Repo. Si raccomanda di non lasciarlo abilitato o almeno di non lasciarlo abilitato quando si aggiornano tutti i pacchetti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>Un&apos;opzione più sicura è installare i pacchetti individualmente con MX Installa Programmi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Seleziona il repository di APT e i sorgenti che vuoi usare:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt non riesce a rilevare il repo più veloce.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="561"/>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>Could not detect fastest repo.</source>
        <translation>Non si riesce a rilevare il repo più veloce.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Could not download original APT files.</source>
        <translation>Non si riesce a scaricare i file di APT originali.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>Le sorgenti di APT originali sono state ripristinate a quelle previste per l&apos;attuale release. I file delle sorgenti, aggiunte dall&apos;utente in /etc/apt/sources.list.d/, non sono stati toccati.</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as root.</source>
        <translation>Devi eseguire questo programma come amministratore</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation type="unfinished">Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished">Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation type="unfinished">Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Chiudi</translation>
    </message>
</context>
</TS>
